//
//  AMHelpPageController.h
//  HelpViewer
//
//  Created by Andreas on 03.04.11.
//


#import "AMHelpPageController.h"
#import "AMHelpViewController.h"


@implementation AMHelpPageController

// Load the view nib and initialize the pageNumber ivar.
- (id)initWithController:(AMHelpViewController *)controller pageNumber:(NSInteger)page
{
    if (self = [super initWithNibName:@"HelpPageView" bundle:nil]) {
		self.helpViewController = controller;
		self.pageNumber = page;
    }
    return self;
}

- (void)dealloc
{
	[webView release];
    [super dealloc];
}

@synthesize helpViewController;
@synthesize pageNumber;
@synthesize pageTitle;

- (void)viewDidLoad
{
	// make web view transparent, so that we don't get ugly flashes when paging fast
	webView.opaque = NO;
	webView.backgroundColor = [UIColor clearColor];

	[self reloadData];
	// stop the view from bouncing
	for (UIView *subview in webView.subviews) {
		if ([[subview class] isSubclassOfClass:[UIScrollView class]]) {
			((UIScrollView *)subview).bounces = NO;
		}
	}
}

- (void)reloadData
{
	NSString *helpFolderName = [helpViewController folderNameForCurrentInterfaceOrientation];
	NSString *pageName = [NSString stringWithFormat:@"page%i", pageNumber+1];
	NSString *path = [[NSBundle mainBundle] pathForResource:pageName ofType:@"html" inDirectory:helpFolderName];
	if (path) {
		NSURL *url = [NSURL fileURLWithPath:path];
		NSURLRequest *request = [NSURLRequest requestWithURL:url];
		[webView loadRequest:request];
	} else {
		[webView loadHTMLString:[NSString stringWithFormat:@"<style type=""text/css"">p {font-family: ""Helvetica"";font-size: 11pt;}</style><p>Page %i is missing</p>", pageNumber+1] baseURL:nil];
	}
}

// we do NOT want to open links inside this view
-(BOOL)webView:(UIWebView *)inWeb shouldStartLoadWithRequest:(NSURLRequest *)inRequest navigationType:(UIWebViewNavigationType)inType
{
	BOOL result = YES;
	if (inType == UIWebViewNavigationTypeLinkClicked) {
		[[UIApplication sharedApplication] openURL:[inRequest URL]];
        result = NO;
    }
    return result;
}

- (void)webViewDidFinishLoad:(UIWebView *)inWeb
{
	self.pageTitle = [inWeb stringByEvaluatingJavaScriptFromString:@"document.title"]; 
	[self.helpViewController pageDidFinishLoad:self];
}

- (void)webView:(UIWebView *)inView didFailLoadWithError:(NSError *)error
{
	[webView loadHTMLString:[NSString stringWithFormat:@"<style type=""text/css"">p {font-family: ""Helvetica"";font-size: 11pt;}</style><p>Did fail to load page %i</p>", pageNumber+1] baseURL:nil];
}


@end
